netapp_ontap.models.snapmirror_destination_creation API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.snapmirror_destination_creation`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SnapmirrorDestinationCreationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SnapmirrorDestinationCreation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bucket_retention: S3BucketRetention POST`

    Information about the retention-mode and default-retention-period configured on the bucket.

  `enabled: bool POST`

    Optional property to create the destination endpoint when establishing a SnapMirror relationship. It is assumed to be "false" if no other property is set and assumed to be "true" if any other property is set.

  `size: Size POST`

    Optional property to specify the size of destination endpoint in bytes. This property is applicable only to ONTAP S3 Bucket endpoints. The minimum size for S3 bucket is 80MB and maximum size is 64TB. If not specified, system will create destination with default size of 800GB.

  `snapshot_locking_enabled: bool POST`

    Optional property to create the destination endpoint with snapshot locking enabled when establishing a SnapMirror relationship. This property is applicable to FlexVol volumes and FlexGroup volumes.

  `storage_service: SnapmirrorDestinationCreationStorageService POST`

    The storage_service field of the snapmirror_destination_creation.

  `tiering: SnapmirrorDestinationCreationTiering POST`

    The tiering field of the snapmirror_destination_creation.